/*
 * Spectator - a desktop app which communicates with router Turris using NETCONF protocol
 * Copyright (C) 2015  CZ.NIC, z. s. p. o. <http://www.nic.cz>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SPECTATOR_CHAT_STRUCTS_H
#define SPECTATOR_CHAT_STRUCTS_H

#include <QtCore>

struct NetconfErrorInfoElement {
	QString name;
	QString content;
};

struct NetconfError {
	QString type;
	QString tag;
	QString serverity;
	QString appTag;
	QString path;
	QString message;
	QList<NetconfErrorInfoElement> info;
};

struct Capability {
	QString base;
	QString revision;

	Capability(QString url);
	Capability(QString base, QString revision) : base(base), revision(revision) {}

	bool covers(Capability &capability);
};

struct ParsedNotification {
	QString id;
	QString severity;
	QString body;
	QDateTime time;
};

struct NethistInterfaceRecord {
	QString name;
	qulonglong rx;
	qulonglong tx;
};

struct NethistRecord {
	QDateTime time;
	QList<NethistInterfaceRecord> interfaces;
	double cpuLoad;
	long boardTemperature;
	long cpuTemperature;
	long usedDiskSpace;
	long availableDiskSpace;
	long totalMemory;
	long freeMemory;
	long buffersMemory;
	long cachedMemory;
};

struct StatsAddress {
	QString type;
	QString address;
};

struct StatsInterface {
	QString name;
	QString use;
	bool up;
	bool down;
	QList<StatsAddress> addresses;
};

struct StatsRecord {
	QString model;
	QString boardName;
	QString kernelVersion;
	QString osVersion;
	QString firewallStatus;
	int firewallAge;
	QString ucollectStatus;
	int ucollectAge;
	float uptime;
	QString hostname;
	QList<StatsInterface> interfaces;
};

struct PkgListRecord {
	QString name;
	QString title;
	QString description;
	bool activated;
};

struct UpdaterActivityRecord {
	QString action;
	QString packageName;
	QString packageVersion;
};

struct UpdaterDataRecord {
	QString status;
	QList<PkgListRecord> userLists;
	QList<UpdaterActivityRecord> lastActivities;
};

struct NeighbourIpRecord {
	QString ipAddress;
	QString nud;
	int connectionCount;
	QDateTime dhcpLease;
	QString hostname;
	int updatedSince;
	int confirmedSince;
	int usedSince;

	NeighbourIpRecord() : connectionCount(0), updatedSince(-1), confirmedSince(-1), usedSince(-1) {}
};

struct NeighbourRecord {
	QString interfaceName;
	QString macAddress;
	QList<NeighbourIpRecord> ips;
};

#endif
